==> paraview-v4.4.0-RC2.zip: paraview-v4.4.0-RC2/Qt/ApplicationComponents/pqStreamingTestingEventPlayer.h <==
/*=========================================================================

   Program: ParaView
   Module:    $RCSfile$

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/
#ifndef __pqStreamingTestingEventPlayer_h
#define __pqStreamingTestingEventPlayer_h

#include "pqWidgetEventPlayer.h"
#include "pqApplicationComponentsModule.h"
#include <QPointer>

class pqViewStreamingBehavior;
/**
Concrete implementation of pqWidgetEventPlayer that handles playback of recorded pqViewStreamingBehavior.

\sa pqEventPlayer
*/

class PQAPPLICATIONCOMPONENTS_EXPORT pqStreamingTestingEventPlayer : public pqWidgetEventPlayer
{
  Q_OBJECT
  typedef pqWidgetEventPlayer Superclass;

public:
  pqStreamingTestingEventPlayer(QObject* p) : Superclass(p) { }
  virtual bool playEvent(QObject*,
    const QString& command, const QString& arguments, bool& error);

  void setViewStreamingBehavior(pqViewStreamingBehavior*);
  pqViewStreamingBehavior* viewStreamingBehavior();
protected:
  QPointer<pqViewStreamingBehavior> StreamingBehavior;

};

#endif

==> paraview-v5.2.0-RC2.zip: paraview-v5.2.0-RC2/Qt/ApplicationComponents/pqStreamingTestingEventPlayer.h <==
/*=========================================================================

   Program: ParaView
   Module:    $RCSfile$

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/
#ifndef pqStreamingTestingEventPlayer_h
#define pqStreamingTestingEventPlayer_h

#include "pqApplicationComponentsModule.h"
#include "pqWidgetEventPlayer.h"
#include <QPointer>

class pqViewStreamingBehavior;
/**
Concrete implementation of pqWidgetEventPlayer that handles playback of recorded pqViewStreamingBehavior.

\sa pqEventPlayer
*/

class PQAPPLICATIONCOMPONENTS_EXPORT pqStreamingTestingEventPlayer : public pqWidgetEventPlayer
{
  Q_OBJECT
  typedef pqWidgetEventPlayer Superclass;

public:
  pqStreamingTestingEventPlayer(QObject* p) : Superclass(p) { }
  using Superclass::playEvent;
  virtual bool playEvent(QObject*,
    const QString& command, const QString& arguments, bool& error);

  void setViewStreamingBehavior(pqViewStreamingBehavior*);
  pqViewStreamingBehavior* viewStreamingBehavior();
protected:
  QPointer<pqViewStreamingBehavior> StreamingBehavior;

};

#endif
